#include <stdio.h>
#include <string.h>
#include <stdlib.h>

#define PARTY 6

typedef enum {
    Normal = 0,
    Fire = 1,
    Water = 2,
    Grass = 3,
    Electric = 4,
    Fighting = 5,
    Psychic = 6
} Type;

typedef struct {
    char name[1000];
    Type type;
    int level, adjusted_level;
} Poke;

void poke_read(Poke* poke) {
    char type_string[100];
    scanf("%s %s %d", poke->name, type_string, &poke->level);
    poke->adjusted_level = poke->level;

    /* a macro to do all the string -> enum conversions */
#define CHECK(name) if (!strcmp(type_string, #name)) poke->type = name;

    /* expand for all of the types */
    CHECK(Normal);
    CHECK(Fire);
    CHECK(Water);
    CHECK(Grass);
    CHECK(Electric);
    CHECK(Fighting);
    CHECK(Psychic);
}

void adjust_level(Poke* poke, Type opponent) {
    /* the table as given in the problem */
    char* adjs[][7] = {{"",   "",    "",   "",   "",    "-5", "-5"}, 
                       {"",   "",    "/2", "*2", "+10", "",   ""}, 
                       {"",   "*2",  "",   "/2", "/2",  "+5", ""}, 
                       {"",   "/2",  "*2", "",   "",    "",   ""}, 
                       {"",   "-10", "*2", "",   "",    "/2", ""}, 
                       {"+5", "",    "-5", "",   "*2",  "",   "/3"}, 
                       {"+5", "",    "",   "",   "",    "*3", ""}};
    
    /* lookup this specific adjustment */
    char* adj = adjs[poke->type][opponent];

    /* if it was empty, return unchanged */
    if (!adj[0]) return;

    /* it must be an operator, get the numeric part as an int */
    int operand = atoi(adj + 1);

    /* apply the operator for each type */
    int new_level;
    switch (adj[0]) {
        case '+': new_level = poke->level + operand; break;
        case '-': new_level = poke->level - operand; break;
        case '*': new_level = poke->level * operand; break;
        case '/': new_level = poke->level / operand; break;
    }

    poke->adjusted_level = new_level;
}

/* find least level of the pokemon */
Poke* least_level(Poke* group, int group_size) {
    /* start with first as choice */
    Poke* current = &group[0];
    int i;
    for (i = 0; i < group_size; i++) {
        if (group[i].level < current->level) {
            current = &group[i];
        }
    }

    return current;
}

/* choose the appropriate pokemon */
Poke* choose(Poke opponent, Poke* party) {
    int needed = opponent.level;

    /* find all that can win */
    Poke can_win[6];
    int can_win_count = 0, i;
    for (i = 0; i < PARTY; i++) {
        if (party[i].adjusted_level > needed) {
            can_win[can_win_count++] = party[i];
        }
    }

    if (can_win_count > 0) {
        /* find one with least level who can win */
        return least_level(can_win, can_win_count);
    } else {
        /* find one with least level at all */
        return least_level(party, PARTY);
    }
}

int main() {
    Poke opponent;
    Poke team[PARTY];
    int i;

    /* read the input, and adjust the levels */
    poke_read(&opponent);
    for (i = 0; i < PARTY; i++) {
        poke_read(&team[i]);
        adjust_level(&team[i], opponent.type);
    }

    /* choose the pokemon we want */
    Poke* choice = choose(opponent, team);
    printf("%s, I choose you!\n", choice->name);
    return 0;
}

