#include <stdio.h>
#include <string.h>

#define MEMSIZE 1000

char* attacks [] = {"Tackle", "Conversion", "Sharpen", "Psybeam"};

/* generic function to match brackets */
int findMatching(char* program, int cmd_index, char self, char goal, int inc) {
    /* start looking one in the direction */
    int i = cmd_index + inc;

    /* maintain a stack since we could have to skip over unrelated brackets */
    int stack = 0;

    /* keep going if were not at goal, or stack is full */
    while ((program[i] != goal) || (stack > 0)) {
        /* if we found another of ourself, add to stack */
        if (program[i] == self)
            stack += 1;

        /* if we hit a goal, dec stack */
        if (program[i] == goal)
            stack -= 1;

        /* move to next */
        i += inc;
    }

    return i;
}

/* match closing or open brackets specifically */
int findClosing(char* program, int cmd_index) {
    return findMatching(program, cmd_index, '[', ']', 1);
}

int findOpening(char* program, int cmd_index) {
    return findMatching(program, cmd_index, ']', '[', -1);
}

/* run a complete program on a porygon */
int simulate(int* data, int mem_index, char* program, int cmd_index) {
    /* check if we are done */
    if (cmd_index >= strlen(program))
        return 0;

    /* handle the next command */
    switch (program[cmd_index]) {
        /* just inc/dec memory index */
        case '>':
            return simulate(data, mem_index + 1, program, cmd_index + 1);
        case '<':
            return simulate(data, mem_index - 1, program, cmd_index + 1);

        /* just inc/dec value at this slot */
        case '+':
            data[mem_index]++;
            return simulate(data, mem_index, program, cmd_index + 1);
        case '-':
            data[mem_index]--;
            return simulate(data, mem_index, program, cmd_index + 1);

        /* print an attack move */
        case '!':
            printf("%s\n", attacks[data[mem_index] - 1]);
            return simulate(data, mem_index, program, cmd_index + 1);

        /* if it's not zero, just move on - if it is zero jump past matching ] */
        case '[':
            if (data[mem_index] != 0)
                return simulate(data, mem_index, program, cmd_index + 1);
            else
                return simulate(data, mem_index, program, findClosing(program, cmd_index) + 1);

        /* jump back to opening [ */
        case ']':
            return simulate(data, mem_index, program, findOpening(program, cmd_index));
    }
}

int main() {
    /* initialize porygon memory */
    int data[MEMSIZE];
    int i;
    for (i = 0; i < MEMSIZE; i++) {
        data[i] = 0;
    }

    /* read the control program */
    char program[1000];
    scanf("%s", program);

    /* run the simulation starting at memory index 0, and command 0 */
    simulate(data, 0, program, 0);

    return 0;
}

