#include <stdio.h>

#define INFINITY 10000

typedef struct {
    int row, col;
} Coord;

/* return the valid adjacent moves for each section */
void getAdjacent(Coord* neighbors, int* count, char area[][11], Coord location) {
    /* start without neighbors */
    *count = 0;

    /* check if a cell is valid */
    int valid(int row, int col) {
        if ((row < 0) || (row > 9) || (col < 0) || (col > 9) || (area[row][col] == 'X'))
            return 0;
        else
            return 1;
    }

    /* try left, right, up, down */
    if (valid(location.row - 1, location.col)) {
        neighbors[*count].row = location.row - 1;
        neighbors[*count].col = location.col;
        *count += 1;
    }
    if (valid(location.row + 1, location.col)) {
        neighbors[*count].row = location.row + 1;
        neighbors[*count].col = location.col;
        *count += 1;
    }
    if (valid(location.row, location.col - 1)) {
        neighbors[*count].row = location.row;
        neighbors[*count].col = location.col - 1;
        *count += 1;
    }
    if (valid(location.row, location.col + 1)) {
        neighbors[*count].row = location.row;
        neighbors[*count].col = location.col + 1;
        *count += 1;
    }
}

/* get the cost of going to a specific part of the map */
int getCost(char area[][11], Coord location) {
    int i;

    /* look at this cell */
    char cell = area[location.row][location.col];

    /* if it's a space or poke center, no cost */
    if ((cell == ' ') || (cell == 'P'))
        return 0;

    /* if it's grass */
    else if (cell == '^') {
        Coord neighbors[4];
        int neighbor_count;
        getAdjacent(neighbors, &neighbor_count, area, location);

        /* if there is a tree nearby, double it */
        for (i = 0; i < neighbor_count; i++) {
            if (area[neighbors[i].row][neighbors[i].col] == 'T') {
                return 2;
            }
        }

        return 1;

        /* otherwise, it's not walkable at all */
    } else {
        return INFINITY;
    }
}

/* find the cost of the shortest path from */
int shortestPath(char area[][11], Coord player, Coord center) {
    int i, j;

    /* maintain tentative costs to get to each cell */
    int tentative[10][10];

    /* set tentative to INFINITY everywhere */
    for (i = 0; i < 10; i++) {
        for (j = 0; j < 10; j++) {
            tentative[i][j] = INFINITY;
        }
    }

    /* set tentative to where player already is to 0 */
    tentative[player.row][player.col] = 0;

    /* maintain which areas we've visited */
    int visited[10][10];
    for (i = 0; i < 10; i++) {
        for (j = 0; j < 10; j++) {
            visited[i][j] = 0;
        }
    }

    /* start where player is */
    Coord curr = player;

    /* loop until done */
    while (1) {
        Coord neighbors[4];
        int neighbor_count;
        getAdjacent(neighbors, &neighbor_count, area, curr);

        for (i = 0; i < neighbor_count; i++) {
            /* distance with this is distance to curr + cost of this cell */
            int distance = tentative[curr.row][curr.col] + getCost(area, neighbors[i]);

            /* if this is better than what we have, replace it */
            if (distance < tentative[neighbors[i].row][neighbors[i].col]) {
                tentative[neighbors[i].row][neighbors[i].col] = distance;
                visited[neighbors[i].row][neighbors[i].col] = 0;
            }
        }

        /* mark curr as visited */
        visited[curr.row][curr.col] = 1;

        /* find the unvisited node with the least tentative cost */
        int smallest = INFINITY;
        curr.row = curr.col = -1;

        for (i = 0; i < 10; i++) {
            for (j = 0; j < 10; j++) {
                if ((!visited[i][j]) && (tentative[i][j] <= smallest)) {
                    smallest = tentative[i][j];
                    curr.row = i;
                    curr.col = j;
                }
            }
        }

        if (curr.row == -1)
            break;
    }

    /* return tentative (now final) cost to destination */
    return tentative[center.row][center.col];
}

/* find the coordinates of a given cell */
Coord findCell(char area[][11], char cell) {
    int i, j;

    for (i = 0; i < 10; i++) {
        for (j = 0; j < 10; j++) {
            if (area[i][j] == cell) {
                Coord place = {i, j};
                return place;
            }
        }
    }
}

int  main() {
    /* read the input */
    char area[10][11];
    int i;

    for (i = 0; i < 10; i++) {
        scanf("%[^\n]\n", area[i]);
    }

    /* find player and the target */
    Coord player = findCell(area, 'W');
    Coord center = findCell(area, 'P');


    /* do it! */
    int cost = shortestPath(area, player, center);
    if (cost < INFINITY)
        printf("Score is %d.\n", cost);
    else
        printf("Impossible to get to the Pokemon Center!\n");

    return 0;
}


