#include <stdio.h>
#include <stdlib.h>

struct Snorlax {
    int no;
    int level;
    int weight;
};

struct Solution {
    int count;
    int* values;
};

/* comparison function for qsort */
int compare(const void* a, const void* b) {
    return ((struct Snorlax*) a)->level - ((struct Snorlax*) b)->level;
}

/* keep global for the best sequence we've found so far */
struct Solution global_best;

/* returns how many snorlaxes we can get in a sequence */
int snorlax_lineup(struct Snorlax* snorlaxes, int n, int i, int* seq, int count) {
    /* check if the solution we are on is the best so far */
    if (count > global_best.count) {
        global_best.count = count;
        for (int i = 0; i < count; i++) {
            global_best.values[i] = snorlaxes[seq[i]].no;
        }
    }
    
    /* base case, no more snorlaxes left */
    if (i == n) {
        return 0;
    }
    
    /* the question here is whether snorlax i should be in the sequence or not
     * we get snorlax i, and also the last snorlax in the sequence (or null)
     */
    struct Snorlax* last = NULL;
    if (count > 0) {
        last = &snorlaxes[seq[count - 1]];
    }
    struct Snorlax* next = &snorlaxes[i];

    /* check if this snorlax can be added */
    int optionA = -1;
    if (!last || ((last->level < next->level) && (last->weight > next->weight))) {
        /* add this snorlax and see how much good it does */
        seq[count] = i;
        optionA = 1 + snorlax_lineup(snorlaxes, n, i + 1, seq, count + 1);
    }

    /* consider not adding this snorlax and seeing how much good it does */
    int optionB = snorlax_lineup(snorlaxes, n, i + 1, seq, count);

    /* return the best of the two options */
    int best = optionA > optionB ? optionA : optionB;

    return best;
}

int  main() {
    /* see how many there are and make space for them */
    int n;
    scanf("%d\n", &n);
    struct Snorlax* snorlaxes = malloc(n * sizeof(struct Snorlax));

    /* read in the input data */
    for (int i = 0; i < n; i++) {
        snorlaxes[i].no = i + 1;
        scanf("%d %d\n", &snorlaxes[i].level, &snorlaxes[i].weight);
    }

    /* make the array of snorlax numbers */
    int* seq = malloc(n * sizeof(int));

    /* sort them in ascending order by level */
    qsort(snorlaxes, n, sizeof(struct Snorlax), &compare);

    /* initialize global answer */
    global_best.count = 0;
    global_best.values = malloc(n * sizeof(int));

    int total = snorlax_lineup(snorlaxes, n, 0, seq, 0);
    printf("There are %d snorlaxes in the sequence:\n", total);
    for (int i = 0; i < total; i++) {
        printf("%d\n", global_best.values[i]);
    }

    /* free our many arrays */
    free(seq);
    free(global_best.values);
    free(snorlaxes);
    
    return 0;
}

